@@ -19,14 +19,3 @@ NULL
 #'
 #' @references Lamura G, Döhner H, Kofahl C, editors. Family carers of older people in Europe: a six-country comparative study. Münster: LIT, 2008.
 NULL
-
-#' @docType data
-#' @title Sample dataset
-#' @name fish
-#' @keywords data
-#'
-#' @description Sample data from the UCLA idre website.
-#'
-#' @references https://stats.idre.ucla.edu/r/dae/zip/
-NULL
-
